const Cache = require('../cache')

/**
 * Hook for invalidating middleware cache for application
 *
 * @param {Object} req - express request object
 * @param {Object} response - the response from the dispatcher, which cointains
 *    the data from the previous controller method.
 * @returns {Object} response - the response to be returned to the user
 */
module.exports = async function invalidateApplicationCacheHook(req, response) {

  try {

    const applicationId = req.headers.applicationid

    const cache = new Cache()
    await cache.invalidateApplication(applicationId)

  } catch(e) {

    req.logger.error('Failed to invalidate application cache', e)

  }

  return response

}
